# Django Rave

## Project Description

This project provides Django integration for [Flutterwave](https://flutterwave.com/) Rave Card payments and subscriptions.

The project is currently being developed and is considered pre-alpha.

# Installation

```bash
pip install djangorave
```

# Development

### Running the example:

```bash
git clone https://github.com/bdelate/django-rave.git
cd django-rave
make build
make dup
```